@@ -88,7 +88,7 @@ available_rblood2plasma <- function(chem.cas=NULL,
     } else {
       if (is.null(chem.cas)) 
       {
-        out <- get_chem_id(chem.cas=chem.cas,chem.name=chem.name)
+        out <- get_chem_id(chem.cas=chem.cas,chem.name=chem.name,dtxsid=dtxsid)
         chem.cas <- out$chem.cas
       }
       if (chem.cas %in% get_cheminfo(species=species,model='schmitt'))
