@@ -1,4 +1,4 @@
-#'Calculate the analytic steady state concentration for model pbtk.
+#'Calculate the analytic steady state plasma concentration for model pbtk.
 #'
 #'This function calculates the analytic steady state plasma or venous blood 
 #'concentrations as a result of infusion dosing.
@@ -11,7 +11,7 @@
 #' the chemical must be identified by either CAS, name, or DTXSIDs
 #'@param parameters Chemical parameters from parameterize_pbtk (for model = 
 #' 'pbtk'), parameterize_3comp (for model = '3compartment), 
-#' parmeterize_1comp(for model = '1compartment') or parameterize_steadystate 
+#' parameterize_1comp(for model = '1compartment') or parameterize_steadystate 
 #' (for model = '3compartmentss'), overrides chem.name and chem.cas.
 #'@param hourly.dose Hourly dose rate mg/kg BW/h.
 #'@param concentration Desired concentration type, 'blood', 'tissue', or default 'plasma'.
@@ -31,7 +31,7 @@
 #'@param ... Additional parameters passed to parameterize function if 
 #' parameters is NULL.
 #'  
-#'@return Steady state concentration in uM units
+#'@return Steady state plasma concentration in mg/L units
 #'
 #'@author Robert Pearce and John Wambaugh
 #'@keywords pbtk
@@ -134,7 +134,7 @@ calc_analytic_css_pbtk <- function(chem.name=NULL,
       pcs <- predict_partitioning_schmitt(parameters =
         parameters[, param.names.schmitt[param.names.schmitt %in% 
         names(parameters)], with = F])
-    }else if (class(parameters) == "list") {
+    }else if (is(parameters,"list")) {
       pcs <- predict_partitioning_schmitt(parameters =
         parameters[param.names.schmitt[param.names.schmitt %in% 
         names(parameters)]])
