@@ -56,7 +56,7 @@
 #' chemical ratio of blood to plasma
 #' @param censored.params The parameters listed in censored.params are sampled
 #' from a normal distribution that is censored for values less than the limit
-#' of detection (specified separately for each paramter). This argument should
+#' of detection (specified separately for each parameter). This argument should
 #' be a list of sub-lists. Each sublist is named for a parameter in
 #' "parameters" and contains two elements: "CV" (coefficient of variation) and
 #' "LOD" (limit of detection, below which parameter values are censored. New
@@ -180,7 +180,7 @@ calc_mc_tk<- function(chem.cas=NULL,
                         parameterize.arg.list=list(
                           default.to.human=FALSE,
                           clint.pvalue.threshold=0.05,
-                          restrictive.clearance = T,
+                          restrictive.clearance = TRUE,
                           regression=TRUE),
                         return.all.sims=FALSE)
 {
