@@ -2,40 +2,113 @@
 #' 
 #' This function provides the information specified in "info=" (can be single entry
 #' or vector) for all chemicals for which a toxicokinetic model can be
-#' paramterized for a given species.
+#' parameterized for a given species. Since different models have different 
+#' requirements and not all chemicals have complete data, this function will 
+#' return different number of chemicals depending on the model specififed.
 #' 
 #' When default.to.human is set to TRUE, and the species-specific data,
-#' Funbound.plasma and Clint, are missing from chem.physical_and_invitro.data,
-#' human values are given instead.
+#' Funbound.plasma and Clint, are missing from 
+#' \code{\link{chem.physical_and_invitro.data}}, human values are given instead.
+#'
+#' In some cases the rapid equilbrium dailysis method (Waters et al., 2008)
+#' fails to yield detectable concentrations for the free fraction of chemical. 
+#' In those cases we assume the compound is highly bound (that is, Fup approaches
+#' zero). For some calculations (for example, steady-state plasma concentration)
+#' there is precendent (Rotroff et al., 2010) for using half the average limit 
+#' of detection, that is, 0.005 (this value is configurable via the argument
+#' fup.lod.default). We do not recomend using other models where 
+#' quantities like partition coefficients must be predicted using Fup. We also
+#' do not recomend including the value 0.005 in training sets for Fup predictive
+#' models.
+#'
+#' \strong{Note} that in some cases the \strong{Funbound.plasma} and the 
+#' \strong{intrinsic clearance} are
+#' \emph{provided as a series of numbers separated by commas}. These values are the 
+#' result of Bayesian analysis and characterize a distribution: the first value
+#' is the median of the distribution, while the second and third values are the 
+#' lower and upper 95th percentile (that is qunatile 2.5 and 97.5) respectively.
+#' For intrinsic clearance a fourth value indicating a p-value for a decrease is
+#' provided. Typically 4000 samples were used for the Bayesian analusis, such
+#' that a p-value of "0" is equivale to "<0.00025". See Wambaugh et al. (2019)
+#' for more details. If argument meadian.only == TRUE then only the median is
+#' reported for parameters with Bayesian analysis distributions. If the 95% 
+#' credible interval is larger than fup.ci.cutoff (defaults
+#' to NULL) then the Fup is treated as too uncertain and the value NA is given.
 #' 
 #' @param info A single character vector (or collection of character vectors)
 #' from "Compound", "CAS", "DTXSID, "logP", "pKa_Donor"," pKa_Accept", "MW", "Clint",
 #' "Clint.pValue", "Funbound.plasma","Structure_Formula", or "Substance_Type". info="all"
 #' gives all information for the model and species.
+#' 
 #' @param species Species desired (either "Rat", "Rabbit", "Dog", "Mouse", or
 #' default "Human").
+#' 
 #' @param fup.lod.default Default value used for fraction of unbound plasma for
 #' chemicals where measured value was below the limit of detection. Default
 #' value is 0.0005.
+#' 
 #' @param model Model used in calculation, 'pbtk' for the multiple compartment
 #' model, '1compartment' for the one compartment model, '3compartment' for
 #' three compartment model, '3compartmentss' for the three compartment model
 #' without partition coefficients, or 'schmitt' for chemicals with logP and
 #' fraction unbound (used in predict_partitioning_schmitt).
+#' 
 #' @param default.to.human Substitutes missing values with human values if
 #' true.
+#' 
 #' @param median.only Use median values only for fup and clint.  Default is FALSE.
+#' 
 #' @param fup.ci.cutoff Cutoff for the level of uncertainty in fup estimates.
 #' This value should be between (0,1). Default is `NULL` specifying no filtering.
+#' 
 #' @param clint.pvalue.threshold Hepatic clearance for chemicals where the in
 #' vitro clearance assay result has a p-values greater than the threshold are
 #' set to zero.
+#' 
 #' @param suppress.messages Whether or not the output messages are suppressed.
 #' 
-#' @return \item{info}{Table/vector containing values specified in "info" for
-#' valid chemicals.}
+#' @return \item{vector/data.table}{Table (if info has multiple entries) or 
+#' vector containing a column for each valid entry 
+#' specified in the argument "info" and a row for each chemical with sufficient
+#' data for the model specified by argument "model":
+#' \tabular{lll}{
+#' \strong{Column} \tab \strong{Description} \tab \strong{units} \cr
+#' Compound \tab The preferred name of the chemical compound \tab none \cr 
+#' CAS \tab The preferred Chemical Abstracts Service Registry Number \tab none \cr  
+#' DTXSID \tab DSSTox Structure ID 
+#' (\url{http://comptox.epa.gov/dashboard}) \tab none \cr 
+#' logP \tab The log10 octanol:water partition coefficient\tab log10 unitless ratio \cr 
+#' MW \tab The chemical compound molecular weight \tab g/mol \cr 
+#' pKa_Accept \tab The hydrogen acceptor equilibria concentrations 
+#' \tab logarithm \cr   
+#' pKa_Donor \tab The hydrogen donor equilibria concentrations 
+#'  \tab logarithm \cr   
+#' [SPECIES].Clint \tab (Primary hepatocyte suspension) 
+#' intrinsic hepatic clearance \tab uL/min/10^6 hepatocytes \cr    
+#' [SPECIES].Clint.pValue \tab Probability that there is no clearance observed. \tab none \cr  
+#' [SPECIES].Funbound.plasma \tab Chemical fraction unbound in presence of 
+#' plasma proteins \tab unitless fraction \cr 
+#' [SPECIES].Rblood2plasma \tab Chemical concentration blood to plasma ratio \tab unitless ratio \cr  
+#' }
+#' }
+#' 
 #' @author John Wambaugh, Robert Pearce, and Sarah E. Davidson
+#' 
 #' @keywords Retrieval
+#' 
+#'@references 
+#' Rotroff, Daniel M., et al. "Incorporating human dosimetry and exposure into 
+#' high-throughput in vitro toxicity screening." Toxicological Sciences 117.2 
+#' (2010): 348-358.
+#' 
+#' Waters, Nigel J., et al. "Validation of a rapid equilibrium dialysis approach 
+#' for the measurement of plasma protein binding." Journal of pharmaceutical 
+#' sciences 97.10 (2008): 4586-4595.
+#'
+#' Wambaugh, John F., et al. "Assessing toxicokinetic uncertainty and 
+#' variability in risk prioritization." Toxicological Sciences 172.2 (2019): 
+#' 235-251.
+#'
 #' @examples
 #' 
 #' \donttest{
@@ -251,6 +324,98 @@ get_cheminfo <- function(info="CAS",
     }
   }
 
+  # Identify the appropriate column for Clint (if needed):
+  species.clint <- paste0(species,'.Clint')
+  species.clint.pvalue <- paste0(species,'.Clint.pValue')
+  # Make sure capitalization matches a table column:
+  if (tolower(species.clint) %in% 
+    tolower(colnames(chem.physical_and_invitro.data)))
+  {
+    species.clint <- colnames(chem.physical_and_invitro.data)[
+      tolower(colnames(chem.physical_and_invitro.data)) ==
+      tolower(species.clint)]
+    species.clint.pvalue <- colnames(chem.physical_and_invitro.data)[
+      tolower(colnames(chem.physical_and_invitro.data)) ==
+      tolower(species.clint.pvalue)]
+  }
+  
+  # Check to see if we need clint:
+  if (tolower("Clint") %in% 
+    unique(tolower(c(necessary.params,info))))   
+  {
+    # Check to see if we will use human data where species data is missing:
+    if (default.to.human)
+    {
+      # Check to see if this is a column that already has data:
+      if (species.clint %in% colnames(chem.physical_and_invitro.data))
+      {
+        # Replace chemicals with NA's only:
+        replace.index <- is.na(chem.physical_and_invitro.data[,species.clint])
+        if (any(replace.index))
+        {
+          chem.physical_and_invitro.data[replace.index,species.clint] <-
+            chem.physical_and_invitro.data[replace.index,'Human.Clint']
+          chem.physical_and_invitro.data[replace.index,species.clint.pvalue] <-
+            chem.physical_and_invitro.data[replace.index,'Human.Clint.pValue']
+          if (!suppress.messages) 
+            warning('Human values substituted for Clint and Clint.pValue.')
+        }
+      } else {
+        chem.physical_and_invitro.data[,species.clint] <-
+          chem.physical_and_invitro.data[,'Human.Clint']
+        chem.physical_and_invitro.data[,species.clint.pvalue] <-
+          chem.physical_and_invitro.data[,'Human.Clint.pValue']
+        if (!suppress.messages) 
+          warning('Human values substituted for Clint and Clint.pValue.')
+      }    
+    }
+    # Check to see if we have a column for this species in the table:
+    if (!(species.clint %in% colnames(chem.physical_and_invitro.data)))  
+    {
+      incomplete.data <- T
+    } else {
+      # Set observed clint values to 0 if clint.pvalue > threshold
+      if (!is.null(clint.pvalue.threshold))
+      {
+        clint.values  <- strsplit(chem.physical_and_invitro.data[,species.clint],
+          split = ",")
+        clint.pvalues <- chem.physical_and_invitro.data[,species.clint.pvalue]
+        # Replace the clint.value with 0 when clint.pvalue > threshold
+        clint.values[lapply(clint.values,length)!=4] <- 
+          ifelse(
+            clint.pvalues[lapply(clint.values,length)!=4] > 
+            clint.pvalue.threshold & 
+            !is.na(clint.pvalues[lapply(clint.values,length)!=4]),
+            yes = "0",
+            no = clint.values[lapply(clint.values,length)!=4]
+          )
+        # Replace the (median,l95,u95) with 0 when clint.pvalue > threshold
+        clint.values[lapply(clint.values,length)==4]<-
+          ifelse(
+            clint.pvalues[lapply(clint.values,length)==4] >
+            clint.pvalue.threshold & 
+            !is.na(clint.pvalues[lapply(clint.values,length)==4]),
+            yes = lapply(clint.values[lapply(clint.values,length)==4],
+            function(x){x<-c(rep("0",3),x[[4]])}),
+            no = clint.values[lapply(clint.values,length)==4]
+          )
+        
+        clint.values <- lapply(clint.values,function(x)paste(x,collapse = ","))
+        chem.physical_and_invitro.data[,species.clint] <- unlist(clint.values)
+        if (!suppress.messages & "CLINT" %in% info)
+          warning(paste(
+            'Clint values with a pvalue >',
+            clint.pvalue.threshold,
+            'were set to 0.'))
+      }    
+    }
+    # Change the necessary parameters to the chem.physical_and_invitro.data col:
+    if (!is.null(species.clint)) 
+    {
+      necessary.params[necessary.params=="Clint"]<-species.clint
+    }
+  }
+
 # Check to see if we need fup (don't we always?)
   if (tolower("Funbound.plasma") %in% 
     unique(tolower(c(necessary.params,info))))
@@ -508,4 +673,4 @@ get_cheminfo <- function(info="CAS",
   } else return.info <- NULL 
     
   return(return.info)
-}
+}
\ No newline at end of file
