@@ -31,6 +31,11 @@
 #' Hispanic','Non-Hispanic White','Non-Hispanic Black','Other')}, to include
 #' all races and ethnicities in their proportions in the NHANES data.
 #' User-supplied vector must contain one or more of these strings.
+#' @param gfr_resid_var Logical value indicating whether or not to include
+#' residual variability when generating GFR values. (Default is TRUE.)
+#' @param ckd_epi_race_coeff Logical value indicating whether or not to use the
+#' "race coefficient" from the CKD-EPI equation when estimating GFR values.
+#' (Default is FALSE.)
 #' @return A data.table where each row represents an individual, and each
 #' column represents a demographic, anthropometric, or physiological parameter.
 #'
@@ -45,8 +50,8 @@
 #' @export httkpop_direct_resample
 httkpop_direct_resample <- function(nsamp=NULL,
                                     gendernum=NULL,
-                                    agelim_years=NULL, 
-                                    agelim_months=NULL,
+                                    agelim_years=c(0,79), 
+                                    agelim_months=c(0,959),
                                     weight_category=c('Underweight',
                                                       'Normal',
                                                       'Overweight',
@@ -58,7 +63,9 @@ httkpop_direct_resample <- function(nsamp=NULL,
                                             'Other Hispanic',
                                             'Non-Hispanic White',
                                             'Non-Hispanic Black',
-                                            'Other')){
+                                            'Other'),
+                                    gfr_resid_var = TRUE,
+                                    ckd_epi_race_coeff = FALSE){
   
   #R CMD CHECK throws notes about "no visible binding for global variable", for
   #each time a data.table column name is used without quotes. To appease R CMD
@@ -77,7 +84,9 @@ httkpop_direct_resample <- function(nsamp=NULL,
                                             agelim_months=agelim_months,
                                             agelim_years=agelim_years,
                                             reths=reths,
-                                            weight_category=weight_category)
+                                            weight_category=weight_category,
+                                            gfr_resid_var = gfr_resid_var,
+                                            ckd_epi_race_coeff = ckd_epi_race_coeff)
   #Compute BMI
   indiv_dt[, bmi_adj:=weight_adj/((height/100)^2)]
   #Assign weight class
@@ -120,7 +129,9 @@ httkpop_direct_resample <- function(nsamp=NULL,
                                                agelim_months=agelim_months,
                                                agelim_years=agelim_years,
                                                reths=reths,
-                                               weight_category=weight_category)
+                                               weight_category=weight_category,
+                                               gfr_resid_var = gfr_resid_var,
+                                               ckd_epi_race_coeff = ckd_epi_race_coeff)
     #Recalculate BMI for the newly redrawn individuals
     indiv_tmp[, bmi_adj:=weight_adj/((height/100)^2)]
     #Check on weight class
