@@ -28,7 +28,12 @@
 #'@param gfr_category The kidney function categories to include in the 
 #'  population. Default is \code{c('Normal','Kidney Disease', 'Kidney Failure')}
 #'  to include all kidney function levels.
-#'
+#' @param gfr_resid_var Logical value indicating whether or not to include
+#' residual variability when generating GFR values. (Default is TRUE.)
+#' @param ckd_epi_race_coeff Logical value indicating whether or not to use the
+#' "race coefficient" from the CKD-EPI equation when estimating GFR values.
+#' (Default is FALSE.)
+#' 
 #'@return A data.table where each row represents an individual, and
 #'  each column represents a demographic, anthropometric, or physiological
 #'  parameter.
@@ -43,8 +48,8 @@
 #' @export httkpop_virtual_indiv
 httkpop_virtual_indiv<- function(nsamp=NULL,
                                  gendernum=NULL,
-                                 agelim_years=NULL, 
-                                 agelim_months=NULL,
+                                 agelim_years=c(0,79), 
+                                 agelim_months=c(0,959),
                                  weight_category=c('Underweight', 
                                                    'Normal',
                                                    'Overweight',
@@ -56,7 +61,9 @@ httkpop_virtual_indiv<- function(nsamp=NULL,
                                          'Other Hispanic',
                                          'Non-Hispanic White',
                                          'Non-Hispanic Black',
-                                         'Other')) {
+                                         'Other'),
+                                 gfr_resid_var = TRUE,
+                                 ckd_epi_race_coeff = FALSE) {
   
   #R CMD CHECK throws notes about "no visible binding for global variable", for
   #each time a data.table column name is used without quotes. To appease R CMD
@@ -78,8 +85,12 @@ httkpop_virtual_indiv<- function(nsamp=NULL,
   #Generate tissue masses and flows.
   indiv_dt <- tissue_masses_flows(tmf_dt=indiv_dt)
   
-  #Estimate GFR (including draw individual values of serum creatinine)
-  indiv_dt<-estimate_gfr(gfrtmp.dt=indiv_dt)
+  #Generate serum creatinine levels
+  indiv_dt <- gen_serum_creatinine(serumcreat.dt = indiv_dt)
+  #Estimate GFR
+  indiv_dt<-estimate_gfr(gfrtmp.dt=indiv_dt,
+                         gfr_resid_var = gfr_resid_var,
+                         ckd_epi_race_coeff = ckd_epi_race_coeff)
   
   #Compute BMI using adjusted individual weights
   indiv_dt[, bmi_adj:=weight_adj/((height/100)^2)]
@@ -132,7 +143,9 @@ httkpop_virtual_indiv<- function(nsamp=NULL,
     #Recompute tissue masses and flows using the new age, height, and weight
     #values
     indiv_tmp<-tissue_masses_flows(tmf_dt=indiv_tmp)
-    #Recompute GFR using the new age values
+    #Recompute serum creatinine levels
+    indiv_tmp <- gen_serum_creatinine(serumcreat.dt = indiv_tmp)
+    #Recompute GFR using the new serum creatinine values
     indiv_tmp<-estimate_gfr(gfrtmp.dt=indiv_tmp)
     #Recompute BMI using the new height, adjusted weight values
     indiv_tmp[, bmi_adj:=weight_adj/((height/100)^2)]
