@@ -6,15 +6,35 @@
 #Analytic expression for steady-state plasma concentration.
 model.list[["3compartment"]]$analytic.css.func <- "calc_analytic_css_3comp"
 
+# When calculating steady-state, which compartment do we test? 
+# ("C" is preprended):
+model.list[["3compartment"]]$steady.state.compartment <- "syscomp"
+
 # Function used for generating model parameters:
 model.list[["3compartment"]]$parameterize.func <- "parameterize_3comp"
 
 # Function called for running the model:
 model.list[["3compartment"]]$solve.func <- "solve_3comp"
 
-# How the tissues from tissue.table are lumped together to form the model:
-# 3 compartment model has only liver and gut compartments; everything else is
-# lumped.
+# Here are the tissues from tissue.data that are considered:
+model.list[["3compartment"]]$alltissues=c(
+  "adipose",
+  "bone",            
+  "brain",           
+  "gut",            
+  "heart",           
+  "kidney",          
+  "liver",           
+  "lung",           
+  "muscle", 
+  "skin",            
+  "spleen",          
+  "red blood cells",
+  "rest")
+
+# Which tissues from tissue.data are not lumped together when forming
+# the model: 3 compartment model has only liver and gut compartments; 
+# everything else is lumped.
 model.list[['3compartment']]$tissuelist = list(
                liver=c("liver"),
                gut=c("gut"))
@@ -129,8 +149,33 @@ model.list[["3compartment"]]$default.monitor.vars <- c(
   "AUC"
   )
 
-# Allowable units:
-model.list[["3compartment"]]$allowed.units <- c('um', 'mg/l')
+
+# Allowable units assigned to dosing input:
+model.list[["3compartment"]]$allowed.units.input <- list(
+       "oral" = c('umol','mg','mg/kg'),
+       "iv" = c('umol','mg','mg/kg'))
+       
+# Allowable units assigned to entries in the output columns of the ode system
+model.list[["3compartment"]]$allowed.units.output <- list(
+              "oral" = c('uM','mg/L','umol','mg','uM*days','mg/L*days'),
+              "iv" = c('uM','mg/L','umol','mg','uM*days','mg/L*days'))
+
+# Default set of units assigned to correspond to each of the time dependent
+# variables of the model system including state variables and any transformed
+# outputs (for example, concentrations calculated from amounts.)
+# AUC values should also be included.
+model.list[["3compartment"]]$compartment.units <-c(
+    "Aintestine"="umol",
+    "Aportven"="umol",
+    "Aliver"="umol",
+    "Asyscomp"="umol",
+    "Ametabolized"="umol",
+    "Atubules"="umol",
+    "Cportven"="uM",
+    "Cliver"="uM",
+    "Csyscomp"="uM",
+    "AUC"="uM*days"
+  )
 
 # These parameters specific the exposure scenario simulated by the model:
 model.list[["3compartment"]]$dosing.params <- c(
@@ -138,17 +183,21 @@ model.list[["3compartment"]]$dosing.params <- c(
   "initial.dose",
   "doses.per.day",
   "dosing.matrix")
-model.list[["3compartment"]]$routes <- c("oral","iv")
+  
+model.list[["3compartment"]]$routes <- list(
+  "oral" = list(
 # We need to know which compartment gets the dose 
-model.list[["3compartment"]]$dose.variable <- list(
-  oral="Aintestine",
-  iv="Asyscomp")
-# Can take the values "add" to add dose C1 <- C1 + dose,
-#"replace" to change the value C1 <- dose
-#or "multiply" to change the value to C1 <- C1*dose
-model.list[["3compartment"]]$dose.type <- list(
-  oral="add",
-  iv="add")
+    "entry.compartment" = "Aintestine",
+# desolve events can take the values "add" to add dose C1 <- C1 + dose,
+# "replace" to change the value C1 <- dose
+# or "multiply" to change the value to C1 <- C1*dose
+    "dose.type" = "add"),
+  "iv" = list(
+    "entry.compartment" = "Asyscomp",
+    "dose.type" = "add")
+  )
+    
+
 
 # ORDERED LIST of state variables (must match Model variables: 
 # States in C code, each of which is associated with a differential equation),
@@ -200,11 +249,6 @@ model.list[["3compartment"]]$httkpop.params <- c(
   "Qliver",
   "Ratioblood2plasma")
 
-#Governs how tissues are lumped:
-model.list[["pbtk"]]$tissue.list <- list(
-               liver=c("liver"),
-               gut=c("gut"))
-
 # Do we need to recalculate partition coefficients when doing Monte Carlo?
 model.list[["3compartment"]]$calcpc <- TRUE
 
@@ -212,4 +256,13 @@ model.list[["3compartment"]]$calcpc <- TRUE
 model.list[["3compartment"]]$firstpass <- FALSE
 
 # Do we ignore the Fups where the value was below the limit of detection?
-model.list[["3compartment"]]$exclude.fup.zero <- T
\ No newline at end of file
+model.list[["3compartment"]]$exclude.fup.zero <- TRUE
+
+# These are the parameter names needed to describe steady-state dosing:
+model.list[["3compartment"]]$css.dosing.params <- c("hourly.dose")
+
+# Filter out volatile compounds with Henry's Law Constant Threshold
+model.list[["3compartment"]]$log.henry.threshold <- c(-4.5)
+
+# Filter out compounds belonging to select chemical classes
+model.list[["3compartment"]]$chem.class.filt <- c("PFAS")
