@@ -10,13 +10,13 @@
 #' Default value of NULL for doses.per.day solves for a single dose.
 #' 
 #' When species is specified as rabbit, dog, or mouse, the function uses the
-#' appropriate physiological data(volumes and flows) but substitues human
+#' appropriate physiological data(volumes and flows) but substitutes human
 #' fraction unbound, partition coefficients, and intrinsic hepatic clearance.
 #' 
 #' AUC is area under plasma concentration curve.
 #' 
 #' Model Figure 
-#' \if{html}{\figure{1comp.png}{options: width="60\%" alt="Figure: One
+#' \if{html}{\figure{1comp.jpg}{options: width="60\%" alt="Figure: One
 #' Compartment Model Schematic"}}
 #' \if{latex}{\figure{1comp.pdf}{options: width=12cm alt="Figure: One
 #' Compartment Model Schematic"}}
@@ -32,14 +32,17 @@
 #' overrides chem.name and chem.cas.
 #' @param days Length of the simulation.
 #' @param tsteps The number time steps per hour.
-#' @param daily.dose Total daily dose, mg/kg BW.
-#' @param dose Amount of a single dose, mg/kg BW. 
+#' @param daily.dose Total daily dose, default is mg/kg BW.
+#' @param dose Amount of a single dose, default is mg/kg BW. 
 #' @param doses.per.day Number of doses per day.
 #' @param species Species desired (either "Rat", "Rabbit", "Dog", or default
 #' "Human").
 #' @param iv.dose Simulates a single i.v. dose if true.
-#' @param output.units Desired units (either "mg/L", "mg", "umol", or default
-#' "uM").
+#' @param input.units Input units of interest assigned to dosing, defaults to
+#' "mg/kg" BW. 
+#' @param output.units A named vector of output units expected for the model
+#' results. Default, NULL, returns model results in units specified in the
+#' 'modelinfo' file. See table below for details.
 #' @param initial.values Vector containing the initial concentrations or
 #' amounts of the chemical in specified tissues with units corresponding to
 #' output.units.  Defaults are zero.
@@ -52,7 +55,7 @@
 #' true.
 #' @param dosing.matrix Vector of dosing times or a matrix consisting of two
 #' columns or rows named "dose" and "time" containing the time and amount, in
-#' mg/kg BW, of each dose.
+#' mg/kg BW by default, of each dose.
 #' @param recalc.clearance Whether or not to recalculate the elimination
 #' rate.
 #' @param recalc.blood2plasma Whether or not to recalculate the blood:plasma
@@ -104,7 +107,9 @@ solve_1comp <- function(chem.name = NULL,
                     suppress.messages=FALSE,
                     species="Human",
                     iv.dose=FALSE,
-                    output.units='uM',
+                    input.units='mg/kg',
+                    # output.units='uM',
+                    output.units=NULL,
                     method="lsoda",rtol=1e-8,atol=1e-12,
                     default.to.human=FALSE,
                     recalc.blood2plasma=FALSE,
@@ -112,7 +117,7 @@ solve_1comp <- function(chem.name = NULL,
                     dosing.matrix=NULL,
                     adjusted.Funbound.plasma=TRUE,
                     regression=TRUE,
-                    restrictive.clearance = T,
+                    restrictive.clearance = TRUE,
                     minimum.Funbound.plasma=0.0001,
                     monitor.vars=NULL,
                     ...)
@@ -138,6 +143,7 @@ solve_1comp <- function(chem.name = NULL,
     monitor.vars=monitor.vars,
     suppress.messages=suppress.messages,
     species=species,
+    input.units=input.units,
     output.units=output.units,
     method=method,rtol=rtol,atol=atol,
     recalc.blood2plasma=recalc.blood2plasma,
